lilypondparsertools.GuileProxy
==============================

.. inheritance-diagram:: abjad.tools.lilypondparsertools.GuileProxy.GuileProxy.GuileProxy
   :private-bases:

.. autoclass:: abjad.tools.lilypondparsertools.GuileProxy.GuileProxy.GuileProxy

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.lilypondparsertools.GuileProxy.GuileProxy.GuileProxy.storage_format

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

Methods
-------

.. automethod:: abjad.tools.lilypondparsertools.GuileProxy.GuileProxy.GuileProxy.acciaccatura

.. automethod:: abjad.tools.lilypondparsertools.GuileProxy.GuileProxy.GuileProxy.appoggiatura

.. automethod:: abjad.tools.lilypondparsertools.GuileProxy.GuileProxy.GuileProxy.bar

.. automethod:: abjad.tools.lilypondparsertools.GuileProxy.GuileProxy.GuileProxy.breathe

.. automethod:: abjad.tools.lilypondparsertools.GuileProxy.GuileProxy.GuileProxy.clef

.. automethod:: abjad.tools.lilypondparsertools.GuileProxy.GuileProxy.GuileProxy.grace

.. automethod:: abjad.tools.lilypondparsertools.GuileProxy.GuileProxy.GuileProxy.key

.. automethod:: abjad.tools.lilypondparsertools.GuileProxy.GuileProxy.GuileProxy.language

.. automethod:: abjad.tools.lilypondparsertools.GuileProxy.GuileProxy.GuileProxy.makeClusters

.. automethod:: abjad.tools.lilypondparsertools.GuileProxy.GuileProxy.GuileProxy.mark

.. automethod:: abjad.tools.lilypondparsertools.GuileProxy.GuileProxy.GuileProxy.oneVoice

.. automethod:: abjad.tools.lilypondparsertools.GuileProxy.GuileProxy.GuileProxy.relative

.. automethod:: abjad.tools.lilypondparsertools.GuileProxy.GuileProxy.GuileProxy.skip

.. automethod:: abjad.tools.lilypondparsertools.GuileProxy.GuileProxy.GuileProxy.slashedGraceContainer

.. automethod:: abjad.tools.lilypondparsertools.GuileProxy.GuileProxy.GuileProxy.time

.. automethod:: abjad.tools.lilypondparsertools.GuileProxy.GuileProxy.GuileProxy.times

.. automethod:: abjad.tools.lilypondparsertools.GuileProxy.GuileProxy.GuileProxy.transpose

.. automethod:: abjad.tools.lilypondparsertools.GuileProxy.GuileProxy.GuileProxy.voiceFour

.. automethod:: abjad.tools.lilypondparsertools.GuileProxy.GuileProxy.GuileProxy.voiceOne

.. automethod:: abjad.tools.lilypondparsertools.GuileProxy.GuileProxy.GuileProxy.voiceThree

.. automethod:: abjad.tools.lilypondparsertools.GuileProxy.GuileProxy.GuileProxy.voiceTwo

Special Methods
---------------

.. automethod:: abjad.tools.lilypondparsertools.GuileProxy.GuileProxy.GuileProxy.__call__

.. automethod:: abjad.tools.lilypondparsertools.GuileProxy.GuileProxy.GuileProxy.__eq__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.lilypondparsertools.GuileProxy.GuileProxy.GuileProxy.__ge__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.lilypondparsertools.GuileProxy.GuileProxy.GuileProxy.__gt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.lilypondparsertools.GuileProxy.GuileProxy.GuileProxy.__le__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.lilypondparsertools.GuileProxy.GuileProxy.GuileProxy.__lt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.lilypondparsertools.GuileProxy.GuileProxy.GuileProxy.__ne__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.lilypondparsertools.GuileProxy.GuileProxy.GuileProxy.__repr__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`
